@@ -1,6 +1,6 @@
-import sys
 import time
 from contextlib import contextmanager
+from contextlib import nullcontext
 
 import attr
 import pytest
@@ -14,14 +14,16 @@ from _pytest.runner import CallInfo
 from _pytest.runner import check_interactive_exception
 from _pytest.unittest import TestCaseFunction
 
-if sys.version_info[:2] < (3, 7):
 
-    @contextmanager
-    def nullcontext():
-        yield
-
-else:
-    from contextlib import nullcontext
+def pytest_addoption(parser):
+    group = parser.getgroup("subtests")
+    group.addoption(
+        "--no-subtests-shortletter",
+        action="store_true",
+        dest="no_subtests_shortletter",
+        default=False,
+        help="Disables subtest output 'dots' in non-verbose mode (EXPERIMENTAL)",
+    )
 
 
 @attr.s
@@ -97,7 +99,7 @@ def pytest_configure(config):
 
 
 def pytest_unconfigure():
-    if hasattr(TestCaseFunction, "_addSubTest"):
+    if hasattr(TestCaseFunction, "addSubTest"):
         del TestCaseFunction.addSubTest
     if hasattr(TestCaseFunction, "failfast"):
         del TestCaseFunction.failfast
@@ -236,7 +238,7 @@ def pytest_report_from_serializable(data):
 
 
 @pytest.hookimpl(tryfirst=True)
-def pytest_report_teststatus(report):
+def pytest_report_teststatus(report, config):
     if report.when != "call" or not isinstance(report, SubTestReport):
         return
 
@@ -245,8 +247,11 @@ def pytest_report_teststatus(report):
 
     outcome = report.outcome
     if report.passed:
-        return f"subtests {outcome}", ",", "SUBPASS"
+        short = "" if config.option.no_subtests_shortletter else ","
+        return f"subtests {outcome}", short, "SUBPASS"
     elif report.skipped:
-        return outcome, "-", "SUBSKIP"
+        short = "" if config.option.no_subtests_shortletter else "-"
+        return outcome, short, "SUBSKIP"
     elif outcome == "failed":
-        return outcome, "u", "SUBFAIL"
+        short = "" if config.option.no_subtests_shortletter else "u"
+        return outcome, short, "SUBFAIL"
